@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from PIL import Image, ImageChops
+from PIL import Image
 
 from pilgram import css
 from pilgram import util
@@ -34,8 +34,8 @@ def hudson(im):
             cb.size,
             [(166, 177, 255), (52, 33, 52)],
             [.5, 1])
-    cs = ImageChops.multiply(cb, cs)
-    cr = Image.blend(cb, cs, .5)
+    cs = css.blending.multiply(cb, cs)
+    cr = Image.blend(cb, cs, .5)  # opacity
 
     cr = css.brightness(cr, 1.2)
     cr = css.contrast(cr, .9)
