@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from PIL import Image
-
 from pilgram import css
 from pilgram import util
 
@@ -30,9 +28,8 @@ def maven(im):
 
     cb = util.or_convert(im, 'RGB')
 
-    cs = util.fill(cb.size, [3, 230, 26])
-    cm = css.blending.hue(cb, cs)
-    cr = Image.blend(cb, cm, .2)
+    cs = util.fill(cb.size, [3, 230, 26, .2])
+    cr = css.blending.hue(cb, cs)
 
     cr = css.sepia(cr, .25)
     cr = css.brightness(cr, .95)
